
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.5',
    'branch_nick': 'patch-0-Release__1_23_5_preparation',
    'revision_id': 'd79e425d40799dda916113ca232be000332dc2ba',
    'revno': 10064
}
